import com.imsl.math.*;
import java.io.*;

public class  SparseMatrixEx2 {
    
    public static class MTXReader {
        private String typecode;
        private SparseMatrix matrix;
        
        public void read(String filename) throws java.io.IOException {
            InputStream s = SparseMatrixEx2.class.getResourceAsStream(filename);
            BufferedReader br = new BufferedReader(new InputStreamReader(s));
            
            // read type code initial line
            String line = br.readLine();
            typecode = line;
            
            // read comment lines if any
            boolean comment = true;
            while (comment) {
                line = br.readLine();
                comment = line.startsWith("%");
            }
            
            // line now contains the size information which needs to be parsed
            String[] str = line.split("( )+");
            int nRows = (Integer.valueOf(str[0].trim())).intValue();
            int nColumns = (Integer.valueOf(str[1].trim())).intValue();
            int nNonZeros = (Integer.valueOf(str[2].trim())).intValue();
            
            // now we're into the data section
            matrix = new SparseMatrix(nRows, nColumns);
            while (true) {
                line = br.readLine();
                if (line == null)  break;
                str = line.split("( )+");
                int i = (Integer.valueOf(str[0].trim())).intValue();
                int j = (Integer.valueOf(str[1].trim())).intValue();
                double x = (Double.valueOf(str[2].trim())).doubleValue();
                matrix.set(i-1, j-1, x);
            }
            br.close();
        }
        
        public String getTypeCode() {
            return this.typecode;
        }        
    }
    
    public static void main(String args[]) throws Exception {
        MTXReader mr = new MTXReader();
        mr.read("bcsstk01.mtx");
        SparseMatrix A = mr.matrix;
        
        // Print the matrix type
        System.out.println("The matrix type is "+ mr.getTypeCode());
        
        // Print the matrix information and its one norm
        System.out.println("The number of rows is " + A.getNumberOfRows());
        int ncols = A.getNumberOfColumns();
        System.out.println("The number of columns is " +ncols);
        long nnz = A.getNumberOfNonZeros();
        System.out.println("The number of nonzero elements is " + nnz);
        System.out.println();
        System.out.println("The 1 norm of the matrix is "+ A.oneNorm());
    }
}
